<?php
namespace SlimSEOPro\Schema\Renderer;

use SlimSEOPro\Schema\Support\Arr;

class PropParser {
	public static function parse( &$schema ) {
		$type   = $schema['type'];
		$fields = &$schema['fields'];

		$fields['@id'] = self::get_id_value( $schema );

		$custom_fields = $fields['custom'] ?? [];
		$custom_fields = self::parse_custom_fields( $custom_fields );
		unset( $fields['custom'] );

		$fields = Arr::undot( $custom_fields, array_merge( [ '@type' => $type ], $fields ) );
	}

	public static function parse_custom_fields( $custom_fields ) {
		if ( empty( $custom_fields ) ) {
			return [];
		}
		$fields = [];
		foreach ( $custom_fields as $field ) {
			$fields[ $field['key'] ] = $field['value'];
		}
		return $fields;
	}

	public static function get_id( array $schema ): string {
		$label = Arr::get( $schema, 'fields._label', $schema['type'] );
		return self::sanitize_id( $label );
	}

	public static function get_id_value( array $schema ): string {
		$id = Arr::get( $schema, 'fields.@id', '{{ current.url }}#{{ id }}' );
		return str_replace( '{{ id }}', self::get_id( $schema ), $id );
	}

	/**
	 * Sanitize id for connecting schemas together.
	 *
	 * @see JavaScript's sanitizeId() function in PropInserter.js.
	 */
	private static function sanitize_id( string $text ): string {
		$id = sanitize_title( $text );
		$id = preg_replace( '/[^a-z0-9_]/', '_', $id ); // Only accepts alphanumeric and underscores.
		$id = preg_replace( '/[ _]{2,}/', '_', $id );   // Remove duplicated `_`.
		$id = trim( $id, '_' );                         // Trim `_`.
		$id = preg_replace( '/^\d+/', '', $id );        // Don't start with numbers.
		$id = trim( $id, '_' );                         // Trim `_` again.

		return $id;
	}
}
